@@ -2,8 +2,16 @@
 # Run this to generate all the initial makefiles, etc.
 set -e
 
-autoreconf -i -f
-intltoolize --force --copy --automake
+srcdir=`dirname $0`
+test -z "$srcdir" && srcdir=.
+
+olddir=`pwd`
+cd $srcdir
+
+mkdir -p m4
+gtkdocize || exit 1
+autoreconf --verbose --force --install || exit $?
+intltoolize --force --copy --automake || exit $?
 
 if test -z "$NOCONFIGURE"; then
     run_configure=true
@@ -20,6 +28,5 @@ else
     run_configure=false
 fi
 
-if test $run_configure = true; then
-    ./configure "$@"
-fi
+cd "$olddir"
+test -n "$NOCONFIGURE" || "$srcdir/configure" "$@"
