@@ -134,7 +134,7 @@ get_visible_text (GtkWidget         *widget,
 }
 
 static gint
-get_vertical_text_height (GtkWidget         *widget)
+get_vertical_text_height (GtkWidget *widget)
 {
   GcalEventWidget *self;
   GtkBorder border, padding;
@@ -247,10 +247,9 @@ gcal_event_widget_set_event_tooltip (GcalEventWidget *self,
                                      GcalEvent       *event)
 {
   g_autoptr (GDateTime) tooltip_start, tooltip_end;
-  g_autofree gchar *start, *end, *escaped_summary;
-  GString *tooltip_mesg;
+  g_autofree gchar *start, *end, *escaped_summary, *escaped_description;
   gboolean allday, multiday, is_ltr;
-  guint description_len;
+  GString *tooltip_desc, *tooltip_mesg;
 
   tooltip_mesg = g_string_new (NULL);
   escaped_summary = g_markup_escape_text (gcal_event_get_summary (event), -1);
@@ -361,35 +360,28 @@ gcal_event_widget_set_event_tooltip (GcalEventWidget *self,
       escaped_location = g_markup_escape_text (gcal_event_get_location (event), -1);
 
       g_string_append (tooltip_mesg, "\n\n");
-      g_string_append_printf (tooltip_mesg, "%s", escaped_location);
+      g_string_append_printf (tooltip_mesg, _("At %s"), escaped_location);
     }
 
-  description_len = g_utf8_strlen (gcal_event_get_description (event), -1);
+  escaped_description = g_markup_escape_text (gcal_event_get_description (event), -1);
+  tooltip_desc = g_string_new (escaped_description);
 
   /* Truncate long descriptions at a white space and ellipsize */
-  if (description_len > 0)
+  if (tooltip_desc->len > 0)
     {
-      g_autofree gchar *escaped_description;
-      GString *tooltip_desc;
-
-      tooltip_desc = g_string_new (gcal_event_get_description (event));
-
       /* If the description is larger than DESC_MAX_CHAR, ellipsize it */
-      if (description_len > DESC_MAX_CHAR)
+      if (g_utf8_strlen (tooltip_desc->str, -1) > DESC_MAX_CHAR)
         {
           g_string_truncate (tooltip_desc, DESC_MAX_CHAR - 1);
           g_string_append (tooltip_desc, "…");
         }
 
-      escaped_description = g_markup_escape_text (tooltip_desc->str, -1);
-
-      g_string_append_printf (tooltip_mesg, "\n\n%s", escaped_description);
-
-      g_string_free (tooltip_desc, TRUE);
+      g_string_append_printf (tooltip_mesg, "\n\n%s", tooltip_desc->str);
     }
 
   gtk_widget_set_tooltip_markup (GTK_WIDGET (self), tooltip_mesg->str);
 
+  g_string_free (tooltip_desc, TRUE);
   g_string_free (tooltip_mesg, TRUE);
 }
 
