@@ -487,13 +487,9 @@ get_widget_parts (gint     first_cell,
                   GArray  *cells,
                   GArray  *lengths)
 {
-  gdouble old_y;
-  gdouble y;
-  gint current_part_length;
   gint i;
-
-  old_y  = -1.0;
-  current_part_length = 0;
+  gint current_part_length;
+  gdouble y, old_y = - 1.0;
 
   if (last_cell < first_cell)
     {
@@ -505,21 +501,24 @@ get_widget_parts (gint     first_cell,
   for (i = first_cell; i <= last_cell; i++)
     {
       if (size_left[i] < natural_height)
-        return FALSE;
-
-      y = vertical_cell_space - size_left[i];
-
-      if (old_y == -1.0 || y != old_y)
         {
-          current_part_length = 1;
-          g_array_append_val (cells, i);
-          g_array_append_val (lengths, current_part_length);
-          old_y = y;
+          return FALSE;
         }
       else
         {
-          current_part_length++;
-          g_array_index (lengths, gint, lengths->len - 1) = current_part_length;
+          y = vertical_cell_space - size_left[i];
+          if (y != old_y)
+            {
+              current_part_length = 1;
+              g_array_append_val (cells, i);
+              g_array_append_val (lengths, current_part_length);
+              old_y = y;
+            }
+          else
+            {
+              current_part_length++;
+              g_array_index (lengths, gint, lengths->len - 1) = current_part_length;
+            }
         }
     }
 
@@ -1973,7 +1972,7 @@ gcal_month_view_button_press (GtkWidget      *widget,
   if (pressed_indicator && g_hash_table_contains (ppriv->overflow_cells, GINT_TO_POINTER (clicked_cell)))
     self->pressed_overflow_indicator = clicked_cell;
 
-  return GDK_EVENT_PROPAGATE;
+  return TRUE;
 }
 
 /**
