@@ -515,6 +515,42 @@ gcal_week_grid_draw (GtkWidget *widget,
                              cell_height);
     }
 
+  /* Vertical lines */
+  for (i = 0; i < 7; i++)
+    {
+      if (ltr)
+        x = column_width * i;
+      else
+        x = width - column_width * i;
+
+      cairo_move_to (cr, ALIGNED (x), 0);
+      cairo_rel_line_to (cr, 0, height);
+    }
+
+  /* Horizontal lines */
+  for (i = 1; i < 24; i++)
+    {
+      cairo_move_to (cr, 0, ALIGNED ((height / 24.0) * i));
+      cairo_rel_line_to (cr, width, 0);
+    }
+
+  cairo_stroke (cr);
+
+  /* Dashed lines between the vertical lines */
+  cairo_set_dash (cr, dashed, 2, 0);
+
+  for (i = 0; i < 24; i++)
+    {
+      cairo_move_to (cr, 0, ALIGNED ((height / 24.0) * i + (height / 48.0)));
+      cairo_rel_line_to (cr, width, 0);
+    }
+
+  cairo_stroke (cr);
+
+  gtk_style_context_restore (context);
+
+  GTK_WIDGET_CLASS (gcal_week_grid_parent_class)->draw (widget, cr);
+
   /* Today column */
   today_column = get_today_column (GCAL_WEEK_GRID (widget));
 
@@ -552,42 +588,6 @@ gcal_week_grid_draw (GtkWidget *widget,
       gtk_style_context_restore (context);
     }
 
-  /* Vertical lines */
-  for (i = 0; i < 7; i++)
-    {
-      if (ltr)
-        x = column_width * i;
-      else
-        x = width - column_width * i;
-
-      cairo_move_to (cr, ALIGNED (x), 0);
-      cairo_rel_line_to (cr, 0, height);
-    }
-
-  /* Horizontal lines */
-  for (i = 1; i < 24; i++)
-    {
-      cairo_move_to (cr, 0, ALIGNED ((height / 24.0) * i));
-      cairo_rel_line_to (cr, width, 0);
-    }
-
-  cairo_stroke (cr);
-
-  /* Dashed lines between the vertical lines */
-  cairo_set_dash (cr, dashed, 2, 0);
-
-  for (i = 0; i < 24; i++)
-    {
-      cairo_move_to (cr, 0, ALIGNED ((height / 24.0) * i + (height / 48.0)));
-      cairo_rel_line_to (cr, width, 0);
-    }
-
-  cairo_stroke (cr);
-
-  gtk_style_context_restore (context);
-
-  GTK_WIDGET_CLASS (gcal_week_grid_parent_class)->draw (widget, cr);
-
   /* Fire the redraw timeout if needed */
   if (self->redraw_timeout_id == 0)
     {
@@ -798,7 +798,7 @@ gcal_week_grid_button_press (GtkWidget      *widget,
 
   gtk_widget_queue_draw (widget);
 
-  return GDK_EVENT_PROPAGATE;
+  return GDK_EVENT_STOP;
 }
 
 static gboolean
@@ -989,9 +989,7 @@ gcal_week_grid_drag_drop (GtkWidget      *widget,
   drop_cell = get_dnd_cell (widget, x, y);
   event_widget = gtk_drag_get_source_widget (context);
 
-  week_start = NULL;
-  dnd_date = NULL;
-  new_end = NULL;
+  week_start = dnd_date = NULL;
 
   if (!GCAL_IS_EVENT_WIDGET (event_widget))
     return FALSE;
